--- ircd.orig/src/channel_mode.c	Wed Nov 28 14:47:49 2001
+++ ircd-hybrid-7beta9/src/channel_mode.c	Mon Feb 18 05:10:06 2002
@@ -435,6 +435,8 @@
     *mbuf++ = 'n';
   if (chptr->mode.mode & MODE_HIDEOPS)
     *mbuf++ = 'a';
+  if (chptr->mode.mode & MODE_NOCOLOR)
+    *mbuf++ = 'c';
   if (chptr->mode.limit)
   {
     *mbuf++ = 'l';
@@ -2029,7 +2031,7 @@
   {chm_nosuch, NULL},
   {chm_hideops, NULL},                            /* a */
   {chm_ban, NULL},                                /* b */
-  {chm_nosuch, NULL},                             /* c */
+  {chm_simple, (void *) MODE_NOCOLOR},            /* c */
   {chm_nosuch, NULL},                             /* d */
   {chm_except, NULL},                             /* e */
   {chm_nosuch, NULL},                             /* f */
--- ircd.orig/modules/m_message.c	Fri Dec  7 23:53:53 2001
+++ ircd-hybrid-7beta9/modules/m_message.c	Wed Feb 20 23:35:19 2002
@@ -96,6 +96,8 @@
                          struct Client *client_p,
                          struct Client *source_p, char *nick, char *text);
 
+static void strip_format_flags( char* text );
+
 struct Message privmsg_msgtab = {
   "PRIVMSG", 0, 0, 1, 0, MFLG_SLOW | MFLG_UNREG, 0L,
   {m_unregistered, m_privmsg, m_privmsg, m_privmsg}
@@ -484,6 +486,7 @@
     if (result == CAN_SEND_OPV ||
         !flood_attack_channel(p_or_n, source_p, vchan, chname))
     {
+      if ( MyClient( client_p ) && NoColorChannel( chptr ) ) strip_format_flags( text );
       sendto_channel_butone(client_p, source_p, vchan, command, ":%s", text);
     }
   }
@@ -894,3 +897,63 @@
     }
   }
 }
+
+static void
+strip_format_flags( char *text )
+{
+  char *srcIter = text;
+  char *destIter = text;
+  int removeColor = 0;
+  
+  
+  for( ;*srcIter; ++srcIter )
+  {
+     switch( removeColor )
+     {
+	case 1:
+	   /* 
+	    * first character after color flag 
+	    * must not be a digit
+	    */
+	   if( IsDigit( *srcIter ) ) 
+	     {
+	       /*
+		* omit the next character only if *srcIter == '1'
+		*/
+	       removeColor = ( *srcIter == '1' ) ? 2 : 0;
+	     }
+	   else
+	     {
+	      removeColor = 0;
+	      *destIter++ = *srcIter;
+	     }
+	   break;
+
+	case 2:
+	   /*
+	    * 2nd character after color flag
+	    * can be a digit, but must not 
+	    * we get here whenever the last character is '1'
+	    */
+	   if( !IsDigit( *srcIter ) || *srcIter > '5' ) *destIter++ = *srcIter;
+	   removeColor = 0;
+	   break;
+
+	default:
+     
+	   switch( *srcIter )
+	   {
+	      case 2: /* bold */
+	      case 31: /* underlined */
+		 break;
+	      case 3: /* color */
+		 removeColor = 1;
+		 break;
+	      default:
+		 *destIter++ = *srcIter;
+	   }
+     }
+  }
+
+  *destIter = '\0'; /* terminate */
+ }
--- ircd-test/ircd-hybrid-7beta9/include/channel_mode.h	Wed Nov 28 13:34:43 2001
+++ ircd-hybrid-7beta9/include/channel_mode.h	Mon Feb 18 01:15:21 2002
@@ -105,6 +105,7 @@
 #define MODE_INVEX	0x2000
 #define MODE_HIDEOPS    0x4000
 #define MODE_LIMIT      0x8000
+#define MODE_NOCOLOR    0x1000
 
 /*
  * mode flags which take another parameter (With PARAmeterS)
@@ -122,6 +123,7 @@
 #define HiddenChannel(x)        ((x) && ((x)->mode.mode & MODE_PRIVATE))
 #define PubChannel(x)           ((!x) || ((x)->mode.mode &\
                                  (MODE_PRIVATE | MODE_SECRET)) == 0)
+#define NoColorChannel(x)       ((x) && ((x)->mode.mode & MODE_NOCOLOR))
 
 struct ChModeChange
 {
